@@ -283,6 +283,46 @@ def test_set_mix_folders_secrets(cli_runner, vault_with_token):
     assert vault_with_token.db == {"a/b/c": {"value": "d"}}
 
 
+def test_set_all(cli_runner, vault_with_token):
+
+    result = cli_runner.invoke(cli.cli, ["set-all"], input="""a/b: {"c": "d"}""")
+
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "Done"
+    assert vault_with_token.db == {"a/b": {"c": "d"}}
+
+
+def test_set_all_wrong_type(cli_runner, vault_with_token):
+    result = cli_runner.invoke(cli.cli, ["set-all"], input="""[1, 2, 3]""")
+    assert result.exit_code != 0
+    error = "Error: Mapping expected format is a mapping of paths to secret objects"
+    assert result.stdout.strip() == error
+    assert vault_with_token.db == {}
+
+
+def test_set_all_force(cli_runner, vault_with_token):
+    vault_with_token.db = {"a/b": {"c": "d"}}
+    result = cli_runner.invoke(
+        cli.cli, ["set-all", "--no-force"], input="""a/b: {"c": "e"}"""
+    )
+    assert result.exit_code != 0
+    error = (
+        "Error: Secret already exists at a/b for key: c\nUse -f to force overwriting"
+    )
+    assert result.stdout.strip() == error
+    assert vault_with_token.db == {"a/b": {"c": "d"}}
+
+
+def test_set_all_mix(cli_runner, vault_with_token):
+    vault_with_token.db = {"a/b": {"c": "d"}}
+    result = cli_runner.invoke(cli.cli, ["set-all"], input="""a: {"e": "f"}""")
+
+    assert result.exit_code != 0
+    error = "Error: Cannot create a secret at 'a' because it is already a folder containing a/b"
+    assert result.stdout.strip() == error
+    assert vault_with_token.db == {"a/b": {"c": "d"}}
+
+
 def test_delete(cli_runner, vault_with_token):
 
     vault_with_token.db = {"a": {"value": "foo"}, "b": {"value": "bar"}}
@@ -296,7 +336,7 @@ def test_env(cli_runner, vault_with_token, mocker):
     exec_command = mocker.patch("vault_cli.environment.exec_command")
 
     vault_with_token.db = {"foo/bar": {"value": "yay"}, "foo/baz": {"value": "yo"}}
-    cli_runner.invoke(cli.cli, ["env", "--path", "foo", "--", "echo", "yay"])
+    cli_runner.invoke(cli.cli, ["env", "--envvar", "foo", "--", "echo", "yay"])
 
     _, kwargs = exec_command.call_args
     assert kwargs["command"] == ("echo", "yay")
@@ -309,17 +349,28 @@ def test_env_error(cli_runner, vault_with_token, mocker):
 
     vault_with_token.forbidden_get_paths.add("foo")
 
-    cli_runner.invoke(cli.cli, ["env", "--path", "foo", "--", "echo", "yay"])
+    cli_runner.invoke(cli.cli, ["env", "--envvar", "foo", "--", "echo", "yay"])
 
     exec_command.assert_not_called()
 
 
+def test_env_envvar_format_error(cli_runner):
+    result = cli_runner.invoke(
+        cli.cli, ["env", "--envvar", ":foo", "--", "echo", "yay"]
+    )
+
+    assert result.exit_code != 0
+    assert "Cannot omit the path if a filter key is provided" in result.output
+
+
 def test_env_error_force_sub_error(cli_runner, vault_with_token, mocker):
     exec_command = mocker.patch("vault_cli.environment.exec_command")
 
     vault_with_token.forbidden_get_paths.add("foo")
 
-    cli_runner.invoke(cli.cli, ["env", "--path", "foo", "--force", "--", "echo", "yay"])
+    cli_runner.invoke(
+        cli.cli, ["env", "--envvar", "foo", "--force", "--", "echo", "yay"]
+    )
 
     exec_command.assert_called()
 
@@ -329,7 +380,9 @@ def test_env_error_force_main_error(cli_runner, vault_with_token, mocker):
 
     vault_with_token.forbidden_list_paths.add("foo")
 
-    cli_runner.invoke(cli.cli, ["env", "--path", "foo", "--force", "--", "echo", "yay"])
+    cli_runner.invoke(
+        cli.cli, ["env", "--envvar", "foo", "--force", "--", "echo", "yay"]
+    )
 
     exec_command.assert_called()
 
@@ -341,7 +394,7 @@ def test_env_prefix(cli_runner, vault_with_token, mocker):
         "foo/bar": {"value": "yay"},
         "foo/baz": {"user": "yo", "password": "xxx"},
     }
-    cli_runner.invoke(cli.cli, ["env", "--path", "foo=prefix", "--", "echo", "yay"])
+    cli_runner.invoke(cli.cli, ["env", "--envvar", "foo=prefix", "--", "echo", "yay"])
 
     _, kwargs = exec_command.call_args
     assert kwargs["command"] == ("echo", "yay")
@@ -361,9 +414,9 @@ def test_env_filter_key(cli_runner, vault_with_token, mocker):
         cli.cli,
         [
             "env",
-            "--path",
+            "--envvar",
             "foo/baz:user=MYNAME",
-            "--path",
+            "--envvar",
             "foo/baz:password",
             "--",
             "echo",
@@ -382,7 +435,7 @@ def test_env_omit_single_key(cli_runner, vault_with_token, mocker):
 
     vault_with_token.db = {"foo/bar": {"value": "yay"}, "foo/baz": {"password": "yo"}}
     cli_runner.invoke(
-        cli.cli, ["env", "--path", "foo", "--omit-single-key", "--", "echo", "yay"]
+        cli.cli, ["env", "--envvar", "foo", "--omit-single-key", "--", "echo", "yay"]
     )
 
     _, kwargs = exec_command.call_args
@@ -391,6 +444,40 @@ def test_env_omit_single_key(cli_runner, vault_with_token, mocker):
     assert kwargs["environment"]["FOO_BAZ"] == "yo"
 
 
+def test_env_file(cli_runner, vault_with_token, mocker, tmp_path):
+    mocker.patch("vault_cli.environment.exec_command")
+
+    path = tmp_path / "foo"
+    vault_with_token.db = {"foo/bar": {"value": "yay"}}
+    cli_runner.invoke(
+        cli.cli, ["env", "--file", f"foo/bar:value={path}", "--", "echo", "yay"]
+    )
+    assert path.read_text() == "yay\n"
+
+
+def test_env_file_format_error(cli_runner, vault_with_token, mocker, tmp_path):
+    mocker.patch("vault_cli.environment.exec_command")
+
+    vault_with_token.db = {"foo/bar": {"value": "yay"}}
+    result = cli_runner.invoke(
+        cli.cli, ["env", "--file", "foo/bar", "--", "echo", "yay"]
+    )
+    assert result.exit_code != 0
+    assert "expects both a vault path and a filesystem path" in result.output
+
+
+def test_env_file_yaml(cli_runner, vault_with_token, mocker, tmp_path):
+    mocker.patch("vault_cli.environment.exec_command")
+
+    path = tmp_path / "foo"
+    vault_with_token.db = {"foo/bar": {"value": "yay"}}
+    cli_runner.invoke(
+        cli.cli,
+        ["env", "--file", f"foo/bar={path}", "--", "echo", "yay"],
+    )
+    assert path.read_text() == "---\nvalue: yay\n"
+
+
 def test_main(environ, mocker):
     mock_cli = mocker.patch("vault_cli.cli.cli")
 
@@ -811,3 +898,20 @@ def test_ensure_str():
 def test_ensure_str_wrong():
     with pytest.raises(exceptions.VaultWrongType):
         cli.ensure_str(1, "bar")
+
+
+@pytest.mark.parametrize(
+    "input, output",
+    [
+        ("aa:bb=cc", ("aa", "bb", "cc")),
+        ("aa:bb", ("aa", "bb", "")),
+        ("aa=cc", ("aa", "", "cc")),
+        ("aa", ("aa", "", "")),
+        (":bb=cc", ("", "bb", "cc")),
+        ("=cc", ("", "", "cc")),
+        (":bb", ("", "bb", "")),
+        ("", ("", "", "")),
+    ],
+)
+def test_get_env_parts(input, output):
+    assert cli.get_env_parts(input) == output
