@@ -378,9 +378,60 @@ def set_(
     try:
         client_obj.set_secret(path=path, value=json_value, force=force, update=update)
     except exceptions.VaultOverwriteSecretError as exc:
-        raise click.ClickException(
-            f"Secret already exists at {exc.path}. Use -f to force overwriting."
-        )
+        raise click.ClickException(f"{exc}\nUse -f to force overwriting")
+    except exceptions.VaultMixSecretAndFolder as exc:
+        raise click.ClickException(str(exc))
+    click.echo("Done")
+
+
+@cli.command("set-all")
+@click.pass_obj
+@click.option(
+    "--update/--clear",
+    default=True,
+    help="Update the current kv mapping or replace the its content",
+)
+@click.option(
+    "--force/--no-force",
+    "-f",
+    is_flag=True,
+    default=None,
+    help="In case the path already holds a secret, allow overwriting it "
+    "(this is necessary only if --safe-write is set).",
+)
+@click.argument(
+    "yaml_file",
+    default="-",
+    type=click.File(),
+)
+@handle_errors()
+def set_all(
+    client_obj: client.VaultClientBase,
+    update: bool,
+    force: Optional[bool],
+    yaml_file: TextIO,
+):
+    """
+    Set multiple secrets at once from a yaml mapping.
+    \b
+    Mapping expected format:
+    path/to/secret/a:
+        somekey: mysecret
+        otherkey: othersecret
+    path/to/secret/a:
+        yetanotherkey: [the, secret, is, a, list]
+    """
+    secrets = yaml.safe_load(yaml_file)
+    error = "Mapping expected format is a mapping of paths to secret objects"
+    if not isinstance(secrets, dict) or not all(
+        isinstance(v, dict) for v in secrets.values()
+    ):
+        raise click.ClickException(error)
+
+    try:
+        client_obj.set_secrets(secrets=secrets, force=force, update=update)
+    except exceptions.VaultOverwriteSecretError as exc:
+        raise click.ClickException(f"{exc}\nUse -f to force overwriting")
     except exceptions.VaultMixSecretAndFolder as exc:
         raise click.ClickException(str(exc))
     click.echo("Done")
@@ -402,16 +453,39 @@ def delete(client_obj: client.VaultClientBase, name: str, key: Optional[str]) ->
 @cli.command("env")
 @click.option(
     "-p",
+    "--envvar",
     "--path",
     multiple=True,
-    required=True,
-    help="Folder or single item. Pass several times to load multiple values. You can use --path mypath=prefix or --path mypath:key=prefix if you want to change the generated names of the environment variables",
+    help="""
+    Load a secret from this path into one or more environment variables. Secret can be a
+    folder or single item. Pass several times to load secrets from different paths. You
+    can use --envvar mypath=prefix or --envvar mypath:key=prefix if you want to change
+    the generated names of the environment variables. --path is the original option
+    name, --envvar was added later for clarity, both work identically, and neither is
+    formerly deprecated. See command help for details.
+    """,
+)
+@click.option(
+    "--file",
+    multiple=True,
+    help="""
+    Write a secret from this path into a file on the filesystem. Expected format is
+    path/in/vault[:key]=/path/in/filesystem . This option is meant to be used when
+    your command can only read its inputs from a file and not from the environment (e.g.
+    secret keys, ...). It's highly recommended to only use the option when provided with
+    a secure private temporary filesystem. Writing to a physical disk should be avoided
+    when possible. If the secret a collection (object or array), it's dumped in YAML
+    format.
+    """,
 )
 @click.option(
     "-o",
     "--omit-single-key/--no-omit-single-key",
     default=False,
-    help="When the secret has only one key, don't use that key to build the name of the environment variable",
+    help="""
+    When the secret has only one key, don't use that key to build the name of the
+    environment variable. This option doesn't affect --file.
+    """,
 )
 @click.option(
     "-f",
@@ -424,42 +498,48 @@ def delete(client_obj: client.VaultClientBase, name: str, key: Optional[str]) ->
 @handle_errors()
 def env(
     client_obj: client.VaultClientBase,
-    path: Sequence[str],
+    envvar: Sequence[str],
+    file: Sequence[str],
     omit_single_key: bool,
     force: bool,
     command: Sequence[str],
 ) -> NoReturn:
     """
-    Launch a command, loading secrets in environment.
+    Write secrets to disk, load secrets in environment variable, then  lauch a command.
 
-    Strings are exported as-is, other types (including booleans, nulls, dicts, lists)
-    are exported JSON-encoded.
+    Secrets stored as strings are loaded as-is. Secrets of any other type exported as an
+    environment variable are JSON-encoded. Secrets of any other type written to a file
+    are YAML-encoded.
+
+    LOADING ENVIRONMENT VARIABLES
 
     If the path ends with `:key` then only one key of the mapping is used and its name is the name of the key.
 
-    VARIABLE NAMES
-
     By default the name is build upon the relative path to the parent of the given path (in parameter) and the name of the keys in the value mapping.
     Let's say that we have stored the mapping `{'username': 'me', 'password': 'xxx'}` at path `a/b/c`
 
-    Using `--path a/b` will inject the following environment variables: B_C_USERNAME and B_C_PASSWORD
-    Using `--path a/b/c` will inject the following environment variables: C_USERNAME and C_PASSWORD
-    Using `--path a/b/c:username` will only inject `USERNAME=me` in the environment.
+    Using `--envvar a/b` will inject the following environment variables: B_C_USERNAME and B_C_PASSWORD
+    Using `--envvar a/b/c` will inject the following environment variables: C_USERNAME and C_PASSWORD
+    Using `--envvar a/b/c:username` will only inject `USERNAME=me` in the environment.
 
     You can customize the variable names generation by appending `=SOME_PREFIX` to the path.
     In this case the part corresponding to the base path is replace by your prefix.
 
-    Using `--path a/b=FOO` will inject the following environment variables: FOO_C_USERNAME and FOO_C_PASSWORD
-    Using `--path a/b/c=FOO` will inject the following environment variables: FOO_USERNAME and FOO_PASSWORD
-    Using `--path a/b/c:username=FOO` will inject `FOO=me` in the environment.
+    Using `--envvar a/b=FOO` will inject the following environment variables: FOO_C_USERNAME and FOO_C_PASSWORD
+    Using `--envvar a/b/c=FOO` will inject the following environment variables: FOO_USERNAME and FOO_PASSWORD
+    Using `--envvar a/b/c:username=FOO` will inject `FOO=me` in the environment.
     """
-    paths = list(path) or [""]
+    envvars = list(envvar) or []
+    files = list(file) or []
 
     env_secrets = {}
 
-    for path in paths:
-        path_with_key, _, prefix = path.partition("=")
-        path, _, filter_key = path_with_key.partition(":")
+    for path in envvars:
+        path, key, prefix = get_env_parts(path)
+        if not path and key:
+            raise click.BadOptionUsage(
+                "envvar", "Cannot omit the path if a filter key is provided"
+            )
 
         env_updates = {}
         env_updates = environment.get_envvars(
@@ -467,16 +547,38 @@ def env(
             path=path,
             prefix=prefix,
             omit_single_key=omit_single_key,
-            filter_key=filter_key,
+            filter_key=key,
         )
 
         env_secrets.update(env_updates)
 
+    for file in files:
+        path, key, filesystem_path = get_env_parts(file)
+        if not (path and filesystem_path):
+            raise click.BadOptionUsage(
+                "file", "--file expects both a vault path and a filesystem path"
+            )
+        secret_obj = client_obj.get_secret(path=path, key=key or None)
+
+        if not isinstance(secret_obj, (list, dict)):
+            secret = str(secret_obj).strip() + "\n"
+        else:
+            secret = yaml.safe_dump(
+                secret_obj, default_flow_style=False, explicit_start=True
+            )
+        pathlib.Path(filesystem_path).write_text(secret)
+
     if bool(client_obj.errors) and not force:
         raise click.ClickException("There was an error while reading the secrets.")
     environment.exec_command(command=command, environment=env_secrets)
 
 
+def get_env_parts(value: str) -> Tuple[str, str, str]:
+    part12, _, part3 = value.partition("=")
+    part1, _, part2 = part12.partition(":")
+    return part1, part2, part3
+
+
 @cli.command("dump-config")
 @click.pass_obj
 @handle_errors()
@@ -544,9 +646,7 @@ def mv(
         ):
             click.echo(f"Move '{old_path}' to '{new_path}'")
     except exceptions.VaultOverwriteSecretError as exc:
-        raise click.ClickException(
-            f"Secret already exists at {exc.path}. Use -f to force overwriting."
-        )
+        raise click.ClickException(f"{exc}\nUse -f to force overwriting")
     except exceptions.VaultMixSecretAndFolder as exc:
         raise click.ClickException(str(exc))
 
@@ -576,9 +676,7 @@ def cp(
         ):
             click.echo(f"Copy '{old_path}' to '{new_path}'")
     except exceptions.VaultOverwriteSecretError as exc:
-        raise click.ClickException(
-            f"Secret already exists at {exc.path}. Use -f to force overwriting."
-        )
+        raise click.ClickException(f"{exc}\nUse -f to force overwriting")
     except exceptions.VaultMixSecretAndFolder as exc:
         raise click.ClickException(str(exc))
 
@@ -616,9 +714,9 @@ def template(client_obj: client.VaultClientBase, template: str, output: TextIO)
         template_text = sys.stdin.read()
         search_path = pathlib.Path.cwd()
     else:
-        with open(template, mode="r") as ftemplate:
-            template_text = ftemplate.read()
-        search_path = pathlib.Path(template).parent
+        template_path = pathlib.Path(template)
+        template_text = template_path.read_text()
+        search_path = template_path.parent
 
     result = client_obj.render_template(template_text, search_path=search_path)
     output.write(result)
